# -*- coding: utf-8 -*-
# original copy from https://djangosnippets.org/snippets/773/

import functools
import math

from django.conf import settings
from django.core.paginator import (InvalidPage, Page, Paginator,
                                   QuerySetPaginator)

__all__ = (
    'InvalidPage',
    'ExPaginator',
    'DiggPaginator',
    'QuerySetDiggPaginator',
)


class ExPaginator(Paginator):
    """
    Adds a ``softlimit`` option to the class. If True, querying a
    page number larger than max. will not fail, but instead return the
    last available page.

    This is useful when the data source can not provide an exact count
    at all times (like some search engines), meaning the user could
    possibly see links to invalid pages at some point which we wouldn't
    want to fail as 404s.

    Can be set by passing either 'softlimit' to the the constructor or setting
    settings.ALDRYN_COMMON_PAGINATION_SOFTLIMIT

    >>> items = range(1, 1000)
    >>> paginator = ExPaginator(items, 10)
    >>> paginator.page(1000)
    Traceback (most recent call last):
    InvalidPage: That page contains no results
    >>> paginator.softlimit = True
    >>> paginator.page(1000)
    <Page 100 of 100>

    # [bug] graceful handling of non-int args
    >>> paginator.page("str")
    Traceback (most recent call last):
    InvalidPage: That page number is not an integer
    """

    def __init__(self, *args, **kwargs):
        self.softlimit = kwargs.pop('softlimit', getattr(settings, 'ALDRYN_COMMON_PAGINATION_SOFTLIMIT', True))
        super(ExPaginator, self).__init__(*args, **kwargs)

    def _ensure_int(self, num, e):
        # see Django #7307
        try:
            return int(num)
        except ValueError:
            raise e

    def page(self, number):
        try:
            return super(ExPaginator, self).page(number)
        except InvalidPage as error:
            number = self._ensure_int(number, error)
            if number > self.num_pages and self.softlimit:
                return self.page(self.num_pages)
            else:
                raise error


class DiggPaginator(ExPaginator):
    """
    Based on Django's default paginator, it adds "Digg-style" page ranges
    with a leading block of pages, an optional middle block, and another
    block at the end of the page range. They are available as attributes
    on the page:

    {# with: page = digg_paginator.page(1) #}
    {% for num in page.leading_range %} ...
    {% for num in page.main_range %} ...
    {% for num in page.trailing_range %} ...

    Additionally, ``page_range`` contains a nun-numeric ``False`` element
    for every transition between two ranges.

    {% for num in page.page_range %}
        {% if not num %} ...  {# literally output dots #}
        {% else %}{{ num }}
        {% endif %}
    {% endfor %}

    Additional arguments passed to the constructor allow customization of
    how those bocks are constructed:

    body=5, tail=2

    [1] 2 3 4 5 ... 91 92
    |_________|     |___|
    body            tail
              |_____|
              margin

    body=5, tail=2, padding=2

    1 2 ... 6 7 [8] 9 10 ... 91 92
            |_|     |__|
             ^padding^
    |_|     |__________|     |___|
    tail    body             tail

    ``margin`` is the minimum number of pages required between two ranges; if
    there are less, they are combined into one.

    When ``align_left`` is set to ``True``, the paginator operates in a
    special mode that always skips the right tail, e.g. does not display the
    end block unless necessary. This is useful for situations in which the
    exact number of items/pages is not actually known.

    # odd body length
    >>> print DiggPaginator(range(1,1000), 10, body=5).page(1)
    1 2 3 4 5 ... 99 100
    >>> print DiggPaginator(range(1,1000), 10, body=5).page(100)
    1 2 ... 96 97 98 99 100

    # even body length
    >>> print DiggPaginator(range(1,1000), 10, body=6).page(1)
    1 2 3 4 5 6 ... 99 100
    >>> print DiggPaginator(range(1,1000), 10, body=6).page(100)
    1 2 ... 95 96 97 98 99 100

    # leading range and main range are combined when close; note how
    # we have varying body and padding values, and their effect.
    >>> print DiggPaginator(range(1,1000), 10, body=5, padding=2, margin=2).page(3)
    1 2 3 4 5 ... 99 100
    >>> print DiggPaginator(range(1,1000), 10, body=6, padding=2, margin=2).page(4)
    1 2 3 4 5 6 ... 99 100
    >>> print DiggPaginator(range(1,1000), 10, body=5, padding=1, margin=2).page(6)
    1 2 3 4 5 6 7 ... 99 100
    >>> print DiggPaginator(range(1,1000), 10, body=5, padding=2, margin=2).page(7)
    1 2 ... 5 6 7 8 9 ... 99 100
    >>> print DiggPaginator(range(1,1000), 10, body=5, padding=1, margin=2).page(7)
    1 2 ... 5 6 7 8 9 ... 99 100

    # the trailing range works the same
    >>> print DiggPaginator(range(1,1000), 10, body=5, padding=2, margin=2, ).page(98)
    1 2 ... 96 97 98 99 100
    >>> print DiggPaginator(range(1,1000), 10, body=6, padding=2, margin=2, ).page(97)
    1 2 ... 95 96 97 98 99 100
    >>> print DiggPaginator(range(1,1000), 10, body=5, padding=1, margin=2, ).page(95)
    1 2 ... 94 95 96 97 98 99 100
    >>> print DiggPaginator(range(1,1000), 10, body=5, padding=2, margin=2, ).page(94)
    1 2 ... 92 93 94 95 96 ... 99 100
    >>> print DiggPaginator(range(1,1000), 10, body=5, padding=1, margin=2, ).page(94)
    1 2 ... 92 93 94 95 96 ... 99 100

    # all three ranges may be combined as well
    >>> print DiggPaginator(range(1,151), 10, body=6, padding=2).page(7)
    1 2 3 4 5 6 7 8 9 ... 14 15
    >>> print DiggPaginator(range(1,151), 10, body=6, padding=2).page(8)
    1 2 3 4 5 6 7 8 9 10 11 12 13 14 15
    >>> print DiggPaginator(range(1,151), 10, body=6, padding=1).page(8)
    1 2 3 4 5 6 7 8 9 ... 14 15

    # no leading or trailing ranges might be required if there are only
    # a very small number of pages
    >>> print DiggPaginator(range(1,80), 10, body=10).page(1)
    1 2 3 4 5 6 7 8
    >>> print DiggPaginator(range(1,80), 10, body=10).page(8)
    1 2 3 4 5 6 7 8
    >>> print DiggPaginator(range(1,12), 10, body=5).page(1)
    1 2

    # test left align mode
    >>> print DiggPaginator(range(1,1000), 10, body=5, align_left=True).page(1)
    1 2 3 4 5
    >>> print DiggPaginator(range(1,1000), 10, body=5, align_left=True).page(50)
    1 2 ... 48 49 50 51 52
    >>> print DiggPaginator(range(1,1000), 10, body=5, align_left=True).page(97)
    1 2 ... 95 96 97 98 99
    >>> print DiggPaginator(range(1,1000), 10, body=5, align_left=True).page(100)
    1 2 ... 96 97 98 99 100

    # padding: default value
    >>> DiggPaginator(range(1,1000), 10, body=10).padding
    4

    # padding: automatic reduction
    >>> DiggPaginator(range(1,1000), 10, body=5).padding
    2
    >>> DiggPaginator(range(1,1000), 10, body=6).padding
    2

    # padding: sanity check
    >>> DiggPaginator(range(1,1000), 10, body=5, padding=3)
    Traceback (most recent call last):
    ValueError: padding too large for body (max 2)
    """
    def __init__(self, *args, **kwargs):
        self.body = kwargs.pop('body', 10)
        self.tail = kwargs.pop('tail', 2)
        self.align_left = kwargs.pop('align_left', False)
        self.margin = kwargs.pop('margin', 4)  # TODO: make the default relative to body?
        # validate padding value
        max_padding = int(math.ceil(self.body/2.0)-1)
        self.padding = kwargs.pop('padding', min(4, max_padding))
        if self.padding > max_padding:
            raise ValueError('padding too large for body (max %d)' % max_padding)
        super(DiggPaginator, self).__init__(*args, **kwargs)

    def page(self, number, *args, **kwargs):
        """Return a standard ``Page`` instance with custom, digg-specific
        page ranges attached.
        """

        page = super(DiggPaginator, self).page(number, *args, **kwargs)
        number = int(number)  # we know this will work

        # easier access
        num_pages, body, tail, padding, margin = \
            self.num_pages, self.body, self.tail, self.padding, self.margin

        # put active page in middle of main range
        main_range = list(map(int, [
            math.floor(number-body/2.0)+1,  # +1 = shift odd body to right
            math.floor(number+body/2.0)]))
        # adjust bounds
        if main_range[0] < 1:
            main_range = list(map(abs(main_range[0]-1).__add__, main_range))
        if main_range[1] > num_pages:
            main_range = list(map((num_pages-main_range[1]).__add__, main_range))

        # Determine leading and trailing ranges; if possible and appropriate,
        # combine them with the main range, in which case the resulting main
        # block might end up considerable larger than requested. While we
        # can't guarantee the exact size in those cases, we can at least try
        # to come as close as possible: we can reduce the other boundary to
        # max padding, instead of using half the body size, which would
        # otherwise be the case. If the padding is large enough, this will
        # of course have no effect.
        # Example:
        #     total pages=100, page=4, body=5, (default padding=2)
        #     1 2 3 [4] 5 6 ... 99 100
        #     total pages=100, page=4, body=5, padding=1
        #     1 2 3 [4] 5 ... 99 100
        # If it were not for this adjustment, both cases would result in the
        # first output, regardless of the padding value.
        if main_range[0] <= tail+margin:
            leading = []
            main_range = [1, max(body, min(number+padding, main_range[1]))]
            main_range[0] = 1
        else:
            leading = list(range(1, tail+1))
        # basically same for trailing range, but not in ``left_align`` mode
        if self.align_left:
            trailing = []
        else:
            if main_range[1] >= num_pages-(tail+margin)+1:
                trailing = []
                if not leading:
                    # ... but handle the special case of neither leading nor
                    # trailing ranges; otherwise, we would now modify the
                    # main range low bound, which we just set in the previous
                    # section, again.
                    main_range = [1, num_pages]
                else:
                    main_range = [min(num_pages-body+1, max(number-padding, main_range[0])), num_pages]
            else:
                trailing = list(range(num_pages-tail+1, num_pages+1))

        # finally, normalize values that are out of bound; this basically
        # fixes all the things the above code screwed up in the simple case
        # of few enough pages where one range would suffice.
        main_range = [max(main_range[0], 1), min(main_range[1], num_pages)]

        # make the result of our calculations available as custom ranges
        # on the ``Page`` instance.
        page.main_range = list(range(main_range[0], main_range[1]+1))
        page.leading_range = leading
        page.trailing_range = trailing
        page.page_range = functools.reduce(
            lambda x, y: x+((x and y) and [False])+y,
            [page.leading_range, page.main_range, page.trailing_range]
        )

        page.__class__ = DiggPage
        return page


class DiggPage(Page):
    def __str__(self):
        return " ... ".join(
            filter(None, [
                " ".join(map(str, self.leading_range)),
                " ".join(map(str, self.main_range)),
                " ".join(map(str, self.trailing_range))
            ])
        )


class QuerySetDiggPaginator(DiggPaginator, QuerySetPaginator):
    pass


def paginate_by(fallback=15):
    return getattr(settings, 'ALDRYN_COMMON_PAGINATOR_PAGINATE_BY', fallback)



# -*- coding: utf-8 -*-
from django import template
from django.utils.dateformat import format

register = template.Library()


class DateRangeNode(template.Node):
    YEAR_FORMATS = ['y', 'Y']
    MONTH_FORMATS = ['b', 'F', 'M', 'n']
    DAY_FORMATS = ['d', 'j']

    def __init__(self, start_date, end_date, always_show_year=False):
        self.start_date = template.Variable(start_date)
        self.end_date = template.Variable(end_date)
        self.show_year = template.Variable(always_show_year)

    def render(self, context):
        try:
            start_date = self.start_date.resolve(context)
            end_date = self.end_date.resolve(context)
            if self.show_year:
                show_year = self.show_year.resolve(context)
            else:
                show_year = False
        except template.VariableDoesNotExist:
            return ''

        if start_date.year != end_date.year:
            result = u"%s – %s" % (
                format(start_date, 'd.m.Y'), format(end_date, 'd.m.Y'))
            show_year = False
        elif start_date.month != end_date.month:
            result = u"%s – %s" % (
                format(start_date, 'd.m.'), format(end_date, 'd.m.'))
        elif start_date.day != end_date.day:
            result = u"%s.–%s.%s." % (
                format(start_date, 'd'),
                format(end_date, 'd'),
                format(end_date, 'm'),
                )
        else:
            result = format(start_date, 'd.m.')
        if show_year:
            result += format(end_date, 'Y')
        return result


def do_date_range(parser, token):
    chunks = token.split_contents()
    if len(chunks) not in (2, 3, 4):
        raise template.TemplateSyntaxError(
            "%r tag requires one or two arguments" % token.contents.split()[0])
    return DateRangeNode(
        chunks[1],
        chunks[2] if len(chunks) > 2 else chunks[1],
        chunks[3] if len(chunks) == 4 else False
    )


register.tag('date_range', do_date_range)



import datetime

from django.utils.timezone import is_aware, utc
from django.utils.translation import ugettext, ungettext


def timesince_data(d, now=None, reverse=False):
    """
    Takes two datetime objects and returns the time between d and now
    as a list of components, ordered by size.
    e.g. [{'number': 2, 'type': "hours"}, {'number': 10, 'type': "minutes"}] or
    [
        {'number': 1, 'type': "year"},
        {'number': 8, 'type': "months"},
        {'number': 1, 'type': "week"},
        {'number': 2, 'type': "days"},
        {'number': 9, 'type': "hours"},
        {'number': 42, 'type': "minutes"},
    ].
    If d occurs after now, then [{'number': 0, 'type': "minutes"}] is returned.

    Units used are years, months, weeks, days, hours, and minutes.
    Seconds and microseconds are ignored. Unlike django.utils.timesince,
    all the components are returned as a list of dictionaries.
    """
    chunks = (
        (60 * 60 * 24 * 365, lambda n: ungettext('year', 'years', n)),
        (60 * 60 * 24 * 30, lambda n: ungettext('month', 'months', n)),
        (60 * 60 * 24 * 7, lambda n: ungettext('week', 'weeks', n)),
        (60 * 60 * 24, lambda n: ungettext('day', 'days', n)),
        (60 * 60, lambda n: ungettext('hour', 'hours', n)),
        (60, lambda n: ungettext('minute', 'minutes', n))
    )
    # Convert datetime.date to datetime.datetime for comparison.
    if not isinstance(d, datetime.datetime):
        d = datetime.datetime(d.year, d.month, d.day)
    if now and not isinstance(now, datetime.datetime):
        now = datetime.datetime(now.year, now.month, now.day)

    if not now:
        now = datetime.datetime.now(utc if is_aware(d) else None)

    delta = (d - now) if reverse else (now - d)
    # ignore microseconds
    since = delta.days * 24 * 60 * 60 + delta.seconds
    if since <= 0:
        # d is in the future compared to now, stop processing.
        return []
    r = []
    for i, (seconds, name) in enumerate(chunks):
        count = since // seconds
        r.append({'number': count, 'type': name(count)})
    return r


def timesince_data_nonzero(d, now=None, reverse=False):
    return [item for item in timesince_data(d, now, reverse) if item['number'] > 0]


def timesince_data_single(d, now=None, reverse=False):
    r = timesince_data_nonzero(d, now, reverse)
    if r:
        return r[0]
    else:
        return {'number': 0, 'type': ugettext('minutes')}


def timesince_text(d, now=None):
    return ugettext('%(number)d %(type)s') % timesince_data_single(d, now)[0]


def timeuntil_data(d, now=None):
    return timesince_data(d, now, reverse=True)


def timeuntil_data_nonzero(d, now=None):
    return timesince_data_nonzero(d, now, reverse=True)


def timeuntil_data_single(d, now=None):
    return timesince_data_nonzero(d, now, reverse=True)


def timeuntil_text(d, now=None):
    return ugettext('%(number)d %(type)s') % timeuntil_data_nonzero(d, now)[0]



from django.conf import settings


def get_additional_styles(settings_name):
    """
    Get additional styles choices from settings
    """
    choices = []
    raw = getattr(settings, settings_name, False)

    if raw:
        raw_choices = raw.split(',')
        for choice in raw_choices:
            clean = choice.strip()
            choices.append((clean.lower(), clean.title()))
    return choices



from __future__ import unicode_literals

from django.template import Context, Template
from django.test import TestCase


class QueryStringTagTest(TestCase):

    TEMPLATE_PREFIX = "{% load query_string_tools %}"

    def tag_template(self, tag_str):
        return Template('{prefix}{tag}'.format(prefix=self.TEMPLATE_PREFIX,
                                               tag=tag_str))

    def test_dictionary_merging(self):
        ctx = {
            'q_str': {'tag': ['a', 'b'], 'year': 2011, 'month': 2},
            'tags': ['c', 'd'],
            'm': 4,
        }
        template = self.tag_template(
            '{% query_string q_str tag+tags month=m %}')
        rendered = template.render(Context(ctx))
        rendered_args = rendered.lstrip('?').split('&')
        expected_args = [
            'year=2011', 'tag=a', 'tag=b', 'tag=c', 'tag=d', 'month=4']
        self.assertEquals(sorted(expected_args), sorted(rendered_args))



from aldryn_client import forms


class Form(forms.BaseForm):
    paginator_paginate_by = forms.CharField('Paginator: item per page count', required=False)

    def to_settings(self, data, settings):
        settings['ALDRYN_COMMON_PAGINATOR_PAGINATE_BY'] = data['paginator_paginate_by']
        return settings



# -*- coding: utf-8 -*-
from __future__ import absolute_import, unicode_literals

from itertools import chain

from django import forms
from django.template.loader import render_to_string
from django.urls import NoReverseMatch, reverse
from django.utils.encoding import force_text
from django.utils.html import conditional_escape
from django.utils.safestring import mark_safe

import sortedm2m.fields
import sortedm2m.forms


class SortedM2MWidget(sortedm2m.forms.SortedCheckboxSelectMultiple):
    template = 'admin/aldryn_common/widgets/sortedm2m_widget.html'

    def render(self, name, value, attrs=None, choices=()):
        # TODO: make a pull request to sortedm2m to make it easy to override the template
        # TODO: make a pull request to sortedm2m to make it easy to add the addtional
        # TODO: link to admin (or integrate this whole widget)
        if value is None:
            value = []
        has_id = attrs and 'id' in attrs
        final_attrs = self.build_attrs(attrs, name=name)

        # Normalize to strings
        str_values = [force_text(v) for v in value]

        selected = []
        unselected = []

        # get the admin link
        rel_to = self.choices.queryset.model  # this is hacky
        info = (rel_to._meta.app_label, rel_to._meta.object_name.lower())

        for i, (option_value, option_label) in enumerate(chain(self.choices, choices)):
            # If an ID attribute was given, add a numeric index as a suffix,
            # so that the checkboxes don't all have the same ID attribute.
            if has_id:
                final_attrs = dict(final_attrs, id='%s_%s' % (attrs['id'], i))
                label_for = ' for="%s"' % conditional_escape(final_attrs['id'])
            else:
                label_for = ''

            cb = forms.CheckboxInput(final_attrs, check_test=lambda value: value in str_values)
            option_value = force_text(option_value)
            rendered_cb = cb.render(name, option_value)
            option_label = conditional_escape(force_text(option_label))

            try:
                admin_url = reverse(
                    'admin:%s_%s_change' % info,
                    # current_app=self.admin_site.name,
                    args=(option_value,),
                )
            except NoReverseMatch:
                info = (
                    self.admin_site.root_path,
                    rel_to._meta.app_label,
                    rel_to._meta.object_name.lower(),
                    option_value,
                )
                admin_url = '%s%s/%s/change/%s' % info
            # admin_url = (
            #     u'<a href="%s" style="margin-left:10px;"><img src="%sadmin/img/admin/icon_changelink.gif" '
            #     u'width="10" height="10" alt="View current"/></a>'
            # ) % (url, settings.STATIC_URL)
            item = {
                'label_for': label_for,
                'rendered_cb': rendered_cb,
                'option_label': option_label,
                'option_value': option_value,
                'admin_url': admin_url,
            }

            if option_value in str_values:
                selected.append(item)
            else:
                unselected.append(item)

        # re-order `selected` array according str_values which is a set of `option_value`s in the order they should
        # be shown on screen
        ordered = []
        for value in str_values:
            for select in selected:
                if value == select['option_value']:
                    ordered.append(select)
        selected = ordered

        html = render_to_string(
            self.template,
            {'selected': selected, 'unselected': unselected})
        return mark_safe(html)


class SortedM2MFormField(sortedm2m.fields.SortedMultipleChoiceField):
    widget = SortedM2MWidget

    def __init__(self, *args, **kwargs):
        kwargs['widget'] = self.widget
        super(SortedM2MFormField, self).__init__(*args, **kwargs)


class SortedM2MModelField(sortedm2m.fields.SortedManyToManyField):
    default_field_class = SortedM2MFormField

    def formfield(self, **kwargs):
        defaults = {
            'form_class': self.default_field_class,
        }
        defaults.update(kwargs)
        return super(SortedM2MModelField, self).formfield(**defaults)



# -*- coding: utf-8 -*-
from django import template
from django.core.exceptions import ValidationError
from django.core.validators import URLValidator
from django.utils.html import escape
from django.utils.safestring import mark_safe

register = template.Library()


@register.filter()
def html_strong(value, safe=False):
    if not safe:
        value = escape(value)
    return mark_safe(u"<strong>%s</strong>" % value)


@register.filter()
def safe_html_strong(value):
    # same as html_strong, but treat value as safe
    return html_strong(value, safe=True)


@register.filter()
def html_make_anchortag(value, arg=None, safe=False):
    # TODO: for some weird reason "&" in href in the template even for valid
    #       urls and with the mark_safe. The resulting string of this
    #       filter looks correct... but...??!?
    href = value
    try:
        # this must always be a valid url. otherwise it might be used for XSS
        # but we cant blindly escape it, because it may contain "&" which is ok.
        URLValidator(href)
    except ValidationError:
        href = escape(href)
    label = arg or href
    if not safe:
        label = escape(label)
    return mark_safe(u'''<a href="%s">%s</a>''' % (href, label))


@register.filter()
def safe_html_make_anchortag(value, arg=None):
    return html_make_anchortag(value, arg=arg, safe=True)


@register.filter()
def html_make_mail_anchortag(value, arg=None):
    email = value
    label = arg or email
    return mark_safe(u'''<a href="mailto:%s">%s</a>''' % (email, label))



# -*- coding: utf-8 -*-
from aldryn_common import __version__
from setuptools import find_packages, setup

REQUIREMENTS = [
    'aldryn-boilerplates',
    'django-sortedm2m',
    'six',
]

CLASSIFIERS = [
    'Development Status :: 5 - Production/Stable',
    'Environment :: Web Environment',
    'Framework :: Django',
    'Framework :: Django :: 1.11',
    'Framework :: Django :: 2.0',
    'Framework :: Django :: 2.1',
    'Intended Audience :: Developers',
    'License :: OSI Approved :: BSD License',
    'Operating System :: OS Independent',
    'Programming Language :: Python',
    'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    'Topic :: Software Development',
    'Topic :: Software Development :: Libraries :: Application Frameworks',
    'Programming Language :: Python :: 2.7',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
]

setup(
    name='aldryn-common',
    version=__version__,
    description='Common utilities',
    author='Divio AG',
    author_email='info@divio.ch',
    url='https://github.com/aldryn/aldryn-common',
    packages=find_packages(exclude=['tests']),
    license='LICENSE.txt',
    platforms=['OS Independent'],
    install_requires=REQUIREMENTS,
    classifiers=CLASSIFIERS,
    include_package_data=True,
    zip_safe=False,
    test_suite='tests',
)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from __future__ import unicode_literals


def noop_gettext(s):
    return s


gettext = noop_gettext


HELPER_SETTINGS = {
    'TIME_ZONE': 'UTC',
    'INSTALLED_APPS': [
        'aldryn_boilerplates',
        'sortedm2m',
    ],
    'CMS_PERMISSION': True,
    'LANGUAGES': (
        ('en', 'English'),
        ('de', 'German'),
    ),
    'CMS_LANGUAGES': {
        'default': {
            'public': True,
            'hide_untranslated': False,
            'fallbacks': ['en']

        },
        1: [
            {
                'public': True,
                'code': 'en',
                'fallbacks': [u'de'],
                'hide_untranslated': False,
                'name': gettext('en'),
                'redirect_on_fallback': True,
            },
            {
                'public': True,
                'code': 'de',
                'fallbacks': [u'en'],
                'hide_untranslated': False,
                'name': gettext('de'),
                'redirect_on_fallback': True,
            },
        ],
    },
    'EMAIL_BACKEND': 'django.core.mail.backends.locmem.EmailBackend',
    'DEBUG': True,
    'TEMPLATE_DEBUG': True,
    'CACHES': {
        'default': {
            'BACKEND': 'django.core.cache.backends.dummy.DummyCache',
        }
    },
    'MIDDLEWARE': [
        'django.middleware.http.ConditionalGetMiddleware',
        'django.contrib.sessions.middleware.SessionMiddleware',
        'django.contrib.auth.middleware.AuthenticationMiddleware',
        'django.contrib.messages.middleware.MessageMiddleware',
        'django.middleware.csrf.CsrfViewMiddleware',
        'django.middleware.locale.LocaleMiddleware',
        'django.middleware.common.CommonMiddleware',
    ],
}


def run():
    from djangocms_helper import runner
    runner.run('aldryn_common', extra_args=[])


if __name__ == "__main__":
    run()
